@@ -1,5 +1,5 @@
 from itertools import product
-from typing import Union, List, Dict, overload, Optional
+from typing import Union, List, Dict, overload, Optional, Hashable
 
 from pandas import Series, DataFrame, MultiIndex, merge
 from pandas.core.dtypes.inference import is_number
@@ -266,6 +266,30 @@ class Discrete(
             data=data, variables=variables, states=states
         )
 
+    def unique(
+            self, *variables: Hashable,
+            sort_values: bool = True
+    ) -> Union[List[Hashable], DataFrame]:
+        """
+        Return a list of unique values of the given variable, or DataFrame of
+        unique combinations of the given variables.
+
+        :param variables: Variable(s) to find unique values / combinations of.
+        :param sort_values: Sort before returning.
+        """
+        data: DataFrame = self.data.reset_index()
+        if len(variables) == 1:
+            unique = data[variables[0]].unique()
+            if sort_values:
+                unique = sorted(unique)
+            return unique
+        else:
+            variables = list(variables)
+            unique = data[variables].drop_duplicates()
+            if sort_values:
+                unique = unique.sort_values(variables)
+            return unique
+
     def conditional(self, *conditionals) -> Conditional:
         """
         Return a Conditional table of the distribution on the conditional
@@ -338,14 +362,49 @@ class Discrete(
             ).sum()
         else:
             raise TypeError(
-                "Can't calculate the mean for a non-numeric distribution"
+                "Can't calculate the mean for a non-numeric or Nd distribution"
+            )
+
+    def var(self):
+        """
+        Return the variance of the distribution.
+
+        N.B. only works for unidimensional distributions where the variable
+        values are numeric.
+        """
+        if self._is_1d_numeric:
+            mu = self.mean()
+            return (
+                Series(
+                    index=self.data.index,
+                    data=self.data.index.to_series() - mu
+                )
+            ).sum()
+        else:
+            raise TypeError(
+                "Can't calculate the variance for a non-numeric or Nd "
+                "distribution"
             )
 
     def mode(self):
         """
         Return the most likely value(s) of the distribution.
+
+        For a 1D distribution, returns the modal value or list of modal values
+        if there is more than one.
+        For an ND distribution, returns a DataFrame with one column per variable
+        and one row per mode.
         """
-        return self.data.index[self.data.argmax()]
+        data = self.data.loc[self.data == self.data.max()]
+        if len(self.variables) == 1:
+            mode = data.reset_index()[self.variables[0]]
+            if len(mode) > 1:
+                return mode.to_list()
+            else:
+                return mode.iloc[0]
+        else:
+            mode = data.reset_index()[self.variables]
+        return mode
 
     def min(self):
         """
@@ -357,7 +416,7 @@ class Discrete(
             return data.index.min()
         else:
             raise TypeError(
-                "Can't calculate the mean for a non-numeric distribution"
+                "Can't calculate the min for a non-numeric or Nd distribution"
             )
 
     def max(self):
@@ -370,7 +429,7 @@ class Discrete(
             return data.index.max()
         else:
             raise TypeError(
-                "Can't calculate the mean for a non-numeric distribution"
+                "Can't calculate the max for a non-numeric or Nd distribution"
             )
 
     def __mul__(
