@@ -3,8 +3,8 @@ from typing import Union, Tuple, Optional
 from scipy.stats import beta as beta_dist, rv_continuous
 
 from compound_types.built_ins import FloatIterable
-from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
-    BetaFloatDMixin
+from probability.distributions.mixins.attributes import \
+    AlphaFloatDMixin, BetaFloatDMixin
 from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_continuous_1d_mixin import \
     RVContinuous1dMixin
@@ -90,7 +90,9 @@ class Beta(
             if arg is not None:
                 kwargs[kw] = arg
         alpha, beta, loc, scale = beta_dist.fit(
-            data=data, floc=0, fscale=1, **kwargs
+            data=data,
+            floc=-1e-9, fscale=1 + 2e-9,  # avoid fit error when 0 or 1 in data
+            **kwargs
         )
         return Beta(alpha=alpha, beta=beta)
 
