@@ -2,12 +2,12 @@ from typing import Union
 
 from scipy.stats import geom, rv_discrete
 
-from compound_types.built_ins import FloatIterable
+from probability.custom_types.external_custom_types import FloatArray1d
 from probability.distributions.mixins.attributes import PFloatDMixin
-from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import \
     RVDiscrete1dMixin
-from probability.utils import num_format
+from probability.utils import num_format, is_scalar
 
 
 class Geometric(
@@ -49,7 +49,7 @@ class Geometric(
         return 1
 
     @staticmethod
-    def fit(data: FloatIterable) -> 'Geometric':
+    def fit(data: FloatArray1d, **kwargs) -> 'Geometric':
         """
         Fit a Geometric distribution to the data of one or more experiments
         using the maximum likelihood estimate for p.
@@ -63,12 +63,13 @@ class Geometric(
         return Geometric(p=p)
 
     @staticmethod
-    def fits(data: FloatIterable) -> 'Geometric':
+    def fits(data: FloatArray1d, **kwargs) -> 'Geometric':
         """
         Fit a Geometric distribution to the distribution of results of a
         series of experiments using the method of moments.
 
-        https://en.wikipedia.org/wiki/Geometric_distribution#Parameter_estimation
+        https://en.wikipedia.org/wiki/Geometric_distribution
+        #Parameter_estimation
 
         :param data: Iterable of results to fit to. Each value represents the
                      number of trials in an experiment to get 1 success, and
@@ -89,7 +90,7 @@ class Geometric(
 
     def __eq__(self, other: Union['Geometric', int, float]):
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return self.pmf().at(other)
         else:
             return abs(self._p - other._p) < 1e-10
@@ -98,7 +99,7 @@ class Geometric(
             self, other: Union['Geometric', int, float]
     ) -> Union[bool, float]:
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return 1 - self.pmf().at(other)
         else:
             return not self.__eq__(other)
