@@ -3,10 +3,10 @@ from typing import Union
 from scipy.stats import rv_discrete, nbinom
 
 from probability.distributions.mixins.attributes import PFloatDMixin
-from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import \
     RVDiscrete1dMixin
-from probability.utils import num_format
+from probability.utils import num_format, is_scalar
 
 
 class NegativeBinomial(
@@ -28,20 +28,22 @@ class NegativeBinomial(
 
     https://en.wikipedia.org/wiki/Negative_binomial_distribution
     """
-    def __init__(self, r: int, p: float):
+    def __init__(self, r: float, p: float):
         """
         Create a new NegativeBinomial distribution.
 
         :param r: Number of successes we want.
         :param p: Probability of a failure.
         """
-        self._r: int = r
+        self._r: float = r
         self._p: float = p
         self._reset_distribution()
 
     def _reset_distribution(self):
         """
-        https://stackoverflow.com/questions/40846992/alternative-parametrization-of-the-negative-binomial-in-scipy#comment109394209_47406400
+        https://stackoverflow.com/questions/40846992/
+        alternative-parametrization-of-the-negative-binomial-in-scipy
+        #comment109394209_47406400
         """
         self._distribution: rv_discrete = nbinom(
             self._r, 1 - self._p
@@ -85,7 +87,7 @@ class NegativeBinomial(
 
     def __eq__(self, other: Union['NegativeBinomial', int, float]):
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return self.pmf().at(other)
         else:
             return (
@@ -97,7 +99,7 @@ class NegativeBinomial(
             self, other: Union['NegativeBinomial', int, float]
     ) -> Union[bool, float]:
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return 1 - self.pmf().at(other)
         else:
             return not self.__eq__(other)
