@@ -96,21 +96,21 @@ class ContinuousFunction1d(object):
                             line_styles='--', colors=color)
             axf.add_text(x=x_mean, y=self._distribution.pdf(x_mean),
                          text=f'mean={x_mean: 0.3f}', color=color,
-                         ha='center', va='bottom')
+                         h_align='center', v_align='bottom')
         if median:
             x_median = self._distribution.median()
             axf.add_v_lines(x=x_median, y_min=y_min, y_max=y_max,
                             line_styles='-.', colors=color)
             axf.add_text(x=x_median, y=self._distribution.pdf(x_median),
                          text=f'median={x_median: 0.3f}', color=color,
-                         ha='center', va='bottom')
+                         h_align='center', v_align='bottom')
         if mode:
             x_mode = self._parent.mode()
             axf.add_v_lines(x=x_mode, y_min=y_min, y_max=y_max,
                             line_styles='-.', colors=color)
             axf.add_text(x=x_mode, y=self._distribution.pdf(x_mode),
                          text=f'mode={x_mode: 0.3f}', color=color,
-                         ha='center', va='bottom')
+                         h_align='center', v_align='bottom')
         if std:
             x_std = self._distribution.std()
             axf.add_v_lines(x=[x_mean - x_std, x_mean + x_std],
@@ -119,7 +119,7 @@ class ContinuousFunction1d(object):
             axf.add_text(x=x_mean - x_std / 2,
                          y=self._distribution.pdf(x_mean - x_std / 2),
                          text=f'std={x_std: 0.3f}', color=color,
-                         ha='center', va='bottom')
+                         h_align='center', v_align='bottom')
 
         ax.set_xlabel(self._parent.x_label)
 
@@ -136,3 +136,7 @@ class ContinuousFunction1d(object):
                 ax.set_ylabel(self._name)
 
         return ax
+
+    def __str__(self):
+
+        return f'{self._name}[{self._parent}]'
