@@ -1,6 +1,7 @@
 from math import lgamma
+
 from numba import jit
-from numpy import exp
+from numpy import exp, sum, array
 
 
 @jit
@@ -17,9 +18,11 @@ def g0(a, b, c):
 
 @jit
 def hiter(a, b, c, d):
+    h_list = []
     while d > 1:
         d -= 1
-        yield h(a, b, c, d) / d
+        h_list.append(h(a, b, c, d) / d)
+    return array(h_list)
 
 
 @jit
@@ -27,7 +30,8 @@ def g(a, b, c, d):
     return g0(a, b, c) + sum(hiter(a, b, c, d))
 
 
-def prob_bb_greater_exact(alpha_1, beta_1, m_1, n_1, alpha_2, beta_2, m_2, n_2):
+def prob_bb_greater_exact(alpha_1, beta_1, m_1, n_1,
+                          alpha_2, beta_2, m_2, n_2):
 
     return g(a=alpha_1 + m_1, b=beta_1 + n_1 - m_1,
              c=alpha_2 + m_2, d=beta_2 + n_2 - m_2)
